@@ -2,7 +2,7 @@ use std::fmt::{Debug, Display};
 
 use actix_web::{
     http::{self, StatusCode},
-    HttpResponse, HttpResponseBuilder,
+    HttpResponse, HttpResponseBuilder, ResponseError,
 };
 use serde::Serialize;
 use serde_json::json;
@@ -30,6 +30,10 @@ impl ActixWebError {
             status_code,
         }
     }
+
+    pub fn to_error(&self) -> actix_web::error::Error {
+        actix_web::error::InternalError::from_response("", self.error_response()).into()
+    }
 }
 
 impl Display for ActixWebError {
@@ -46,6 +50,11 @@ impl actix_web::error::ResponseError for ActixWebError {
     fn error_response(&self) -> HttpResponse {
         HttpResponseBuilder::new(self.status_code())
             .insert_header(http::header::ContentType(mime::APPLICATION_JSON))
-            .body(json!(&self.error_info).to_string())
+            .body(
+                json!({
+                    "error": &self.error_info
+                })
+                .to_string(),
+            )
     }
 }
